@@ -23,5 +23,14 @@ class NotificationManager:
             raise InternalError() from e
 
 
+class NotificationManagerMock:
+
+    def __init__(self, resource_name: str):
+        pass
+
+    def publish(self, event_type: str, message, group_id: str):
+        pass
+
+
 class InternalError(Exception):
     pass
